@@ -17,6 +17,8 @@ def _get_kwargs(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    include_header: Union[Unset, None, str] = UNSET,
+    invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run/f/{path}".format(client.base_url, workspace=workspace, path=path)
 
@@ -34,6 +36,10 @@ def _get_kwargs(
 
     params["parent_job"] = parent_job
 
+    params["include_header"] = include_header
+
+    params["invisible_to_owner"] = invisible_to_owner
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -67,6 +73,8 @@ def sync_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    include_header: Union[Unset, None, str] = UNSET,
+    invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """run flow by path
 
@@ -76,6 +84,8 @@ def sync_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        include_header (Union[Unset, None, str]):
+        invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunFlowByPathJsonBody):
 
     Returns:
@@ -90,6 +100,8 @@ def sync_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        include_header=include_header,
+        invisible_to_owner=invisible_to_owner,
     )
 
     response = httpx.request(
@@ -109,6 +121,8 @@ async def asyncio_detailed(
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
+    include_header: Union[Unset, None, str] = UNSET,
+    invisible_to_owner: Union[Unset, None, bool] = UNSET,
 ) -> Response[Any]:
     """run flow by path
 
@@ -118,6 +132,8 @@ async def asyncio_detailed(
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
+        include_header (Union[Unset, None, str]):
+        invisible_to_owner (Union[Unset, None, bool]):
         json_body (RunFlowByPathJsonBody):
 
     Returns:
@@ -132,6 +148,8 @@ async def asyncio_detailed(
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
+        include_header=include_header,
+        invisible_to_owner=invisible_to_owner,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
