@@ -18,6 +18,7 @@ def _get_kwargs(
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
+    queue_limit: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run_wait_result/p/{path}".format(client.base_url, workspace=workspace, path=path)
 
@@ -37,6 +38,8 @@ def _get_kwargs(
 
     params["include_header"] = include_header
 
+    params["queue_limit"] = queue_limit
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     json_json_body = json_body.to_dict()
@@ -71,6 +74,7 @@ def sync_detailed(
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
+    queue_limit: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run script by path
 
@@ -81,6 +85,7 @@ def sync_detailed(
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
+        queue_limit (Union[Unset, None, str]):
         json_body (RunWaitResultScriptByPathJsonBody):
 
     Returns:
@@ -96,6 +101,7 @@ def sync_detailed(
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
         include_header=include_header,
+        queue_limit=queue_limit,
     )
 
     response = httpx.request(
@@ -116,6 +122,7 @@ async def asyncio_detailed(
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     include_header: Union[Unset, None, str] = UNSET,
+    queue_limit: Union[Unset, None, str] = UNSET,
 ) -> Response[Any]:
     """run script by path
 
@@ -126,6 +133,7 @@ async def asyncio_detailed(
         scheduled_in_secs (Union[Unset, None, int]):
         parent_job (Union[Unset, None, str]):
         include_header (Union[Unset, None, str]):
+        queue_limit (Union[Unset, None, str]):
         json_body (RunWaitResultScriptByPathJsonBody):
 
     Returns:
@@ -141,6 +149,7 @@ async def asyncio_detailed(
         scheduled_in_secs=scheduled_in_secs,
         parent_job=parent_job,
         include_header=include_header,
+        queue_limit=queue_limit,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
