@@ -47,6 +47,7 @@ class CompletedJob:
         flow_status (Union[Unset, CompletedJobFlowStatus]):
         raw_flow (Union[Unset, CompletedJobRawFlow]):
         language (Union[Unset, CompletedJobLanguage]):
+        mem_peak (Union[Unset, int]):
     """
 
     id: str
@@ -77,6 +78,7 @@ class CompletedJob:
     flow_status: Union[Unset, CompletedJobFlowStatus] = UNSET
     raw_flow: Union[Unset, CompletedJobRawFlow] = UNSET
     language: Union[Unset, CompletedJobLanguage] = UNSET
+    mem_peak: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -123,6 +125,8 @@ class CompletedJob:
         if not isinstance(self.language, Unset):
             language = self.language.value
 
+        mem_peak = self.mem_peak
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -172,6 +176,8 @@ class CompletedJob:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
             field_dict["language"] = language
+        if mem_peak is not UNSET:
+            field_dict["mem_peak"] = mem_peak
 
         return field_dict
 
@@ -254,6 +260,8 @@ class CompletedJob:
         else:
             language = CompletedJobLanguage(_language)
 
+        mem_peak = d.pop("mem_peak", UNSET)
+
         completed_job = cls(
             id=id,
             created_by=created_by,
@@ -283,6 +291,7 @@ class CompletedJob:
             flow_status=flow_status,
             raw_flow=raw_flow,
             language=language,
+            mem_peak=mem_peak,
         )
 
         completed_job.additional_properties = d
