@@ -35,6 +35,7 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
         branch_chosen (Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen]):
         branchall (Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchall]):
         approvers (Union[Unset, List[GetCompletedJobResponse200FlowStatusFailureModuleApproversItem]]):
+        parent_module (Union[Unset, str]):
     """
 
     type: GetCompletedJobResponse200FlowStatusFailureModuleType
@@ -46,6 +47,7 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
     branch_chosen: Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchChosen] = UNSET
     branchall: Union[Unset, GetCompletedJobResponse200FlowStatusFailureModuleBranchall] = UNSET
     approvers: Union[Unset, List[GetCompletedJobResponse200FlowStatusFailureModuleApproversItem]] = UNSET
+    parent_module: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -78,6 +80,8 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
 
                 approvers.append(approvers_item)
 
+        parent_module = self.parent_module
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -101,6 +105,8 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
             field_dict["branchall"] = branchall
         if approvers is not UNSET:
             field_dict["approvers"] = approvers
+        if parent_module is not UNSET:
+            field_dict["parent_module"] = parent_module
 
         return field_dict
 
@@ -147,6 +153,8 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
 
             approvers.append(approvers_item)
 
+        parent_module = d.pop("parent_module", UNSET)
+
         get_completed_job_response_200_flow_status_failure_module = cls(
             type=type,
             id=id,
@@ -157,6 +165,7 @@ class GetCompletedJobResponse200FlowStatusFailureModule:
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
+            parent_module=parent_module,
         )
 
         get_completed_job_response_200_flow_status_failure_module.additional_properties = d
