@@ -17,6 +17,9 @@ class GetSettingsResponse200:
         slack_command_script (Union[Unset, str]):
         auto_invite_domain (Union[Unset, str]):
         auto_invite_operator (Union[Unset, bool]):
+        plan (Union[Unset, str]):
+        customer_id (Union[Unset, str]):
+        webhook (Union[Unset, str]):
     """
 
     workspace_id: Union[Unset, str] = UNSET
@@ -25,6 +28,9 @@ class GetSettingsResponse200:
     slack_command_script: Union[Unset, str] = UNSET
     auto_invite_domain: Union[Unset, str] = UNSET
     auto_invite_operator: Union[Unset, bool] = UNSET
+    plan: Union[Unset, str] = UNSET
+    customer_id: Union[Unset, str] = UNSET
+    webhook: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -34,6 +40,9 @@ class GetSettingsResponse200:
         slack_command_script = self.slack_command_script
         auto_invite_domain = self.auto_invite_domain
         auto_invite_operator = self.auto_invite_operator
+        plan = self.plan
+        customer_id = self.customer_id
+        webhook = self.webhook
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -50,6 +59,12 @@ class GetSettingsResponse200:
             field_dict["auto_invite_domain"] = auto_invite_domain
         if auto_invite_operator is not UNSET:
             field_dict["auto_invite_operator"] = auto_invite_operator
+        if plan is not UNSET:
+            field_dict["plan"] = plan
+        if customer_id is not UNSET:
+            field_dict["customer_id"] = customer_id
+        if webhook is not UNSET:
+            field_dict["webhook"] = webhook
 
         return field_dict
 
@@ -68,6 +83,12 @@ class GetSettingsResponse200:
 
         auto_invite_operator = d.pop("auto_invite_operator", UNSET)
 
+        plan = d.pop("plan", UNSET)
+
+        customer_id = d.pop("customer_id", UNSET)
+
+        webhook = d.pop("webhook", UNSET)
+
         get_settings_response_200 = cls(
             workspace_id=workspace_id,
             slack_name=slack_name,
@@ -75,6 +96,9 @@ class GetSettingsResponse200:
             slack_command_script=slack_command_script,
             auto_invite_domain=auto_invite_domain,
             auto_invite_operator=auto_invite_operator,
+            plan=plan,
+            customer_id=customer_id,
+            webhook=webhook,
         )
 
         get_settings_response_200.additional_properties = d
