@@ -23,6 +23,7 @@ class GetVariableResponse200:
         is_expired (Union[Unset, bool]):
         refresh_error (Union[Unset, str]):
         is_linked (Union[Unset, bool]):
+        is_refreshed (Union[Unset, bool]):
     """
 
     workspace_id: str
@@ -36,6 +37,7 @@ class GetVariableResponse200:
     is_expired: Union[Unset, bool] = UNSET
     refresh_error: Union[Unset, str] = UNSET
     is_linked: Union[Unset, bool] = UNSET
+    is_refreshed: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -51,6 +53,7 @@ class GetVariableResponse200:
         is_expired = self.is_expired
         refresh_error = self.refresh_error
         is_linked = self.is_linked
+        is_refreshed = self.is_refreshed
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -76,6 +79,8 @@ class GetVariableResponse200:
             field_dict["refresh_error"] = refresh_error
         if is_linked is not UNSET:
             field_dict["is_linked"] = is_linked
+        if is_refreshed is not UNSET:
+            field_dict["is_refreshed"] = is_refreshed
 
         return field_dict
 
@@ -104,6 +109,8 @@ class GetVariableResponse200:
 
         is_linked = d.pop("is_linked", UNSET)
 
+        is_refreshed = d.pop("is_refreshed", UNSET)
+
         get_variable_response_200 = cls(
             workspace_id=workspace_id,
             path=path,
@@ -116,6 +123,7 @@ class GetVariableResponse200:
             is_expired=is_expired,
             refresh_error=refresh_error,
             is_linked=is_linked,
+            is_refreshed=is_refreshed,
         )
 
         get_variable_response_200.additional_properties = d
