@@ -45,6 +45,7 @@ class ListQueueResponse200Item:
         flow_status (Union[Unset, ListQueueResponse200ItemFlowStatus]):
         raw_flow (Union[Unset, ListQueueResponse200ItemRawFlow]):
         language (Union[Unset, ListQueueResponse200ItemLanguage]):
+        mem_peak (Union[Unset, int]):
     """
 
     id: str
@@ -73,6 +74,7 @@ class ListQueueResponse200Item:
     flow_status: Union[Unset, ListQueueResponse200ItemFlowStatus] = UNSET
     raw_flow: Union[Unset, ListQueueResponse200ItemRawFlow] = UNSET
     language: Union[Unset, ListQueueResponse200ItemLanguage] = UNSET
+    mem_peak: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -127,6 +129,8 @@ class ListQueueResponse200Item:
         if not isinstance(self.language, Unset):
             language = self.language.value
 
+        mem_peak = self.mem_peak
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -177,6 +181,8 @@ class ListQueueResponse200Item:
             field_dict["raw_flow"] = raw_flow
         if language is not UNSET:
             field_dict["language"] = language
+        if mem_peak is not UNSET:
+            field_dict["mem_peak"] = mem_peak
 
         return field_dict
 
@@ -275,6 +281,8 @@ class ListQueueResponse200Item:
         else:
             language = ListQueueResponse200ItemLanguage(_language)
 
+        mem_peak = d.pop("mem_peak", UNSET)
+
         list_queue_response_200_item = cls(
             id=id,
             running=running,
@@ -302,6 +310,7 @@ class ListQueueResponse200Item:
             flow_status=flow_status,
             raw_flow=raw_flow,
             language=language,
+            mem_peak=mem_peak,
         )
 
         list_queue_response_200_item.additional_properties = d
