@@ -16,6 +16,7 @@ class ListResourceResponse200Item:
         resource_type (str):
         is_oauth (bool):
         is_linked (bool):
+        is_refreshed (bool):
         workspace_id (Union[Unset, str]):
         description (Union[Unset, str]):
         value (Union[Unset, Any]):
@@ -29,6 +30,7 @@ class ListResourceResponse200Item:
     resource_type: str
     is_oauth: bool
     is_linked: bool
+    is_refreshed: bool
     workspace_id: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
     value: Union[Unset, Any] = UNSET
@@ -43,6 +45,7 @@ class ListResourceResponse200Item:
         resource_type = self.resource_type
         is_oauth = self.is_oauth
         is_linked = self.is_linked
+        is_refreshed = self.is_refreshed
         workspace_id = self.workspace_id
         description = self.description
         value = self.value
@@ -62,6 +65,7 @@ class ListResourceResponse200Item:
                 "resource_type": resource_type,
                 "is_oauth": is_oauth,
                 "is_linked": is_linked,
+                "is_refreshed": is_refreshed,
             }
         )
         if workspace_id is not UNSET:
@@ -92,6 +96,8 @@ class ListResourceResponse200Item:
 
         is_linked = d.pop("is_linked")
 
+        is_refreshed = d.pop("is_refreshed")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         description = d.pop("description", UNSET)
@@ -116,6 +122,7 @@ class ListResourceResponse200Item:
             resource_type=resource_type,
             is_oauth=is_oauth,
             is_linked=is_linked,
+            is_refreshed=is_refreshed,
             workspace_id=workspace_id,
             description=description,
             value=value,
