@@ -24,7 +24,9 @@ class ListSchedulesResponse200Item:
         script_path (str):
         is_flow (bool):
         extra_perms (ListSchedulesResponse200ItemExtraPerms):
+        email (str):
         args (Union[Unset, ListSchedulesResponse200ItemArgs]):
+        error (Union[Unset, str]):
     """
 
     path: str
@@ -36,7 +38,9 @@ class ListSchedulesResponse200Item:
     script_path: str
     is_flow: bool
     extra_perms: ListSchedulesResponse200ItemExtraPerms
+    email: str
     args: Union[Unset, ListSchedulesResponse200ItemArgs] = UNSET
+    error: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -51,10 +55,13 @@ class ListSchedulesResponse200Item:
         is_flow = self.is_flow
         extra_perms = self.extra_perms.to_dict()
 
+        email = self.email
         args: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.args, Unset):
             args = self.args.to_dict()
 
+        error = self.error
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -68,10 +75,13 @@ class ListSchedulesResponse200Item:
                 "script_path": script_path,
                 "is_flow": is_flow,
                 "extra_perms": extra_perms,
+                "email": email,
             }
         )
         if args is not UNSET:
             field_dict["args"] = args
+        if error is not UNSET:
+            field_dict["error"] = error
 
         return field_dict
 
@@ -96,6 +106,8 @@ class ListSchedulesResponse200Item:
 
         extra_perms = ListSchedulesResponse200ItemExtraPerms.from_dict(d.pop("extra_perms"))
 
+        email = d.pop("email")
+
         _args = d.pop("args", UNSET)
         args: Union[Unset, ListSchedulesResponse200ItemArgs]
         if isinstance(_args, Unset):
@@ -103,6 +115,8 @@ class ListSchedulesResponse200Item:
         else:
             args = ListSchedulesResponse200ItemArgs.from_dict(_args)
 
+        error = d.pop("error", UNSET)
+
         list_schedules_response_200_item = cls(
             path=path,
             edited_by=edited_by,
@@ -113,7 +127,9 @@ class ListSchedulesResponse200Item:
             script_path=script_path,
             is_flow=is_flow,
             extra_perms=extra_perms,
+            email=email,
             args=args,
+            error=error,
         )
 
         list_schedules_response_200_item.additional_properties = d
